==> ews-javascript-api-0.1.3.tgz: package/js/Core/XmlAttributeNames.js <==
var XmlAttributeNames;
(function (XmlAttributeNames) {
    XmlAttributeNames.XmlNs = "xmlns";
    XmlAttributeNames.Id = "Id";
    XmlAttributeNames.ChangeKey = "ChangeKey";
    XmlAttributeNames.RecurringMasterId = "RecurringMasterId";
    XmlAttributeNames.InstanceIndex = "InstanceIndex";
    XmlAttributeNames.OccurrenceId = "OccurrenceId";
    XmlAttributeNames.Traversal = "Traversal";
    XmlAttributeNames.ViewFilter = "ViewFilter";
    XmlAttributeNames.Offset = "Offset";
    XmlAttributeNames.MaxEntriesReturned = "MaxEntriesReturned";
    XmlAttributeNames.BasePoint = "BasePoint";
    XmlAttributeNames.ResponseClass = "ResponseClass";
    XmlAttributeNames.IndexedPagingOffset = "IndexedPagingOffset";
    XmlAttributeNames.TotalItemsInView = "TotalItemsInView";
    XmlAttributeNames.IncludesLastItemInRange = "IncludesLastItemInRange";
    XmlAttributeNames.BodyType = "BodyType";
    XmlAttributeNames.MessageDisposition = "MessageDisposition";
    XmlAttributeNames.SaveItemToFolder = "SaveItemToFolder";
    XmlAttributeNames.RootItemChangeKey = "RootItemChangeKey";
    XmlAttributeNames.DeleteType = "DeleteType";
    XmlAttributeNames.DeleteSubFolders = "DeleteSubFolders";
    XmlAttributeNames.AffectedTaskOccurrences = "AffectedTaskOccurrences";
    XmlAttributeNames.SendMeetingCancellations = "SendMeetingCancellations";
    XmlAttributeNames.SuppressReadReceipts = "SuppressReadReceipts";
    XmlAttributeNames.FieldURI = "FieldURI";
    XmlAttributeNames.FieldIndex = "FieldIndex";
    XmlAttributeNames.ConflictResolution = "ConflictResolution";
    XmlAttributeNames.SendMeetingInvitationsOrCancellations = "SendMeetingInvitationsOrCancellations";
    XmlAttributeNames.CharacterSet = "CharacterSet";
    XmlAttributeNames.HeaderName = "HeaderName";
    XmlAttributeNames.SendMeetingInvitations = "SendMeetingInvitations";
    XmlAttributeNames.Key = "Key";
    XmlAttributeNames.RoutingType = "RoutingType";
    XmlAttributeNames.MailboxType = "MailboxType";
    XmlAttributeNames.DistinguishedPropertySetId = "DistinguishedPropertySetId";
    XmlAttributeNames.PropertySetId = "PropertySetId";
    XmlAttributeNames.PropertyTag = "PropertyTag";
    XmlAttributeNames.PropertyName = "PropertyName";
    XmlAttributeNames.PropertyId = "PropertyId";
    XmlAttributeNames.PropertyType = "PropertyType";
    XmlAttributeNames.TimeZoneName = "TimeZoneName";
    XmlAttributeNames.ReturnFullContactData = "ReturnFullContactData";
    XmlAttributeNames.ContactDataShape = "ContactDataShape";
    XmlAttributeNames.Numerator = "Numerator";
    XmlAttributeNames.Denominator = "Numerator";
    XmlAttributeNames.Value = "Value";
    XmlAttributeNames.ContainmentMode = "ContainmentMode";
    XmlAttributeNames.ContainmentComparison = "ContainmentComparison";
    XmlAttributeNames.Order = "Order";
    XmlAttributeNames.StartDate = "StartDate";
    XmlAttributeNames.EndDate = "EndDate";
    XmlAttributeNames.Version = "Version";
    XmlAttributeNames.Aggregate = "Aggregate";
    XmlAttributeNames.SearchScope = "SearchScope";
    XmlAttributeNames.Format = "Format";
    XmlAttributeNames.Mailbox = "Mailbox";
    XmlAttributeNames.DestinationFormat = "DestinationFormat";
    XmlAttributeNames.FolderId = "FolderId";
    XmlAttributeNames.ItemId = "ItemId";
    XmlAttributeNames.IncludePermissions = "IncludePermissions";
    XmlAttributeNames.InitialName = "InitialName";
    XmlAttributeNames.FinalName = "FinalName";
    XmlAttributeNames.AuthenticationMethod = "AuthenticationMethod";
    XmlAttributeNames.Time = "Time";
    XmlAttributeNames.Name = "Name";
    XmlAttributeNames.Bias = "Bias";
    XmlAttributeNames.Kind = "Kind";
    XmlAttributeNames.SubscribeToAllFolders = "SubscribeToAllFolders";
    XmlAttributeNames.PublicFolderServer = "PublicFolderServer";
    XmlAttributeNames.IsArchive = "IsArchive";
    XmlAttributeNames.ReturnHighlightTerms = "ReturnHighlightTerms";
    XmlAttributeNames.IsExplicit = "IsExplicit";
    XmlAttributeNames.ClientExtensionUserIdentity = "UserId";
    XmlAttributeNames.ClientExtensionEnabledOnly = "EnabledOnly";
    XmlAttributeNames.SetClientExtensionActionId = "ActionId";
    XmlAttributeNames.ClientExtensionId = "ExtensionId";
    XmlAttributeNames.ClientExtensionIsAvailable = "IsAvailable";
    XmlAttributeNames.ClientExtensionIsMandatory = "IsMandatory";
    XmlAttributeNames.ClientExtensionIsEnabledByDefault = "IsEnabledByDefault";
    XmlAttributeNames.ClientExtensionProvidedTo = "ProvidedTo";
    XmlAttributeNames.ClientExtensionType = "Type";
    XmlAttributeNames.ClientExtensionScope = "Scope";
    XmlAttributeNames.ClientExtensionMarketplaceAssetID = "MarketplaceAssetId";
    XmlAttributeNames.ClientExtensionMarketplaceContentMarket = "MarketplaceContentMarket";
    XmlAttributeNames.ClientExtensionAppStatus = "AppStatus";
    XmlAttributeNames.ClientExtensionEtoken = "Etoken";
    XmlAttributeNames.IsTruncated = "IsTruncated";
    XmlAttributeNames.IsJunk = "IsJunk";
    XmlAttributeNames.MoveItem = "MoveItem";
    XmlAttributeNames.Nil = "nil";
    XmlAttributeNames.Type = "type";
})(XmlAttributeNames = exports.XmlAttributeNames || (exports.XmlAttributeNames = {}));

==> ews-javascript-api-0.3.0.tgz: package/js/Core/XmlAttributeNames.js <==
"use strict";
/**
 * XML attribute names.
 */
var XmlAttributeNames;
(function (XmlAttributeNames) {
    XmlAttributeNames.XmlNs = "xmlns";
    XmlAttributeNames.Id = "Id";
    XmlAttributeNames.ChangeKey = "ChangeKey";
    XmlAttributeNames.RecurringMasterId = "RecurringMasterId";
    XmlAttributeNames.InstanceIndex = "InstanceIndex";
    XmlAttributeNames.OccurrenceId = "OccurrenceId";
    XmlAttributeNames.Traversal = "Traversal";
    XmlAttributeNames.ViewFilter = "ViewFilter";
    XmlAttributeNames.Offset = "Offset";
    XmlAttributeNames.MaxEntriesReturned = "MaxEntriesReturned";
    XmlAttributeNames.BasePoint = "BasePoint";
    XmlAttributeNames.ResponseClass = "ResponseClass";
    XmlAttributeNames.IndexedPagingOffset = "IndexedPagingOffset";
    XmlAttributeNames.TotalItemsInView = "TotalItemsInView";
    XmlAttributeNames.IncludesLastItemInRange = "IncludesLastItemInRange";
    XmlAttributeNames.BodyType = "BodyType";
    XmlAttributeNames.MessageDisposition = "MessageDisposition";
    XmlAttributeNames.SaveItemToFolder = "SaveItemToFolder";
    XmlAttributeNames.RootItemChangeKey = "RootItemChangeKey";
    XmlAttributeNames.DeleteType = "DeleteType";
    XmlAttributeNames.DeleteSubFolders = "DeleteSubFolders";
    XmlAttributeNames.AffectedTaskOccurrences = "AffectedTaskOccurrences";
    XmlAttributeNames.SendMeetingCancellations = "SendMeetingCancellations";
    XmlAttributeNames.SuppressReadReceipts = "SuppressReadReceipts"; //XmlElementNames.SuppressReadReceipts;
    XmlAttributeNames.FieldURI = "FieldURI";
    XmlAttributeNames.FieldIndex = "FieldIndex";
    XmlAttributeNames.ConflictResolution = "ConflictResolution";
    XmlAttributeNames.SendMeetingInvitationsOrCancellations = "SendMeetingInvitationsOrCancellations";
    XmlAttributeNames.CharacterSet = "CharacterSet";
    XmlAttributeNames.HeaderName = "HeaderName";
    XmlAttributeNames.SendMeetingInvitations = "SendMeetingInvitations";
    XmlAttributeNames.Key = "Key";
    XmlAttributeNames.RoutingType = "RoutingType";
    XmlAttributeNames.MailboxType = "MailboxType";
    XmlAttributeNames.DistinguishedPropertySetId = "DistinguishedPropertySetId";
    XmlAttributeNames.PropertySetId = "PropertySetId";
    XmlAttributeNames.PropertyTag = "PropertyTag";
    XmlAttributeNames.PropertyName = "PropertyName";
    XmlAttributeNames.PropertyId = "PropertyId";
    XmlAttributeNames.PropertyType = "PropertyType";
    XmlAttributeNames.TimeZoneName = "TimeZoneName";
    XmlAttributeNames.ReturnFullContactData = "ReturnFullContactData";
    XmlAttributeNames.ContactDataShape = "ContactDataShape";
    XmlAttributeNames.Numerator = "Numerator";
    XmlAttributeNames.Denominator = "Numerator";
    XmlAttributeNames.Value = "Value";
    XmlAttributeNames.ContainmentMode = "ContainmentMode";
    XmlAttributeNames.ContainmentComparison = "ContainmentComparison";
    XmlAttributeNames.Order = "Order";
    XmlAttributeNames.StartDate = "StartDate";
    XmlAttributeNames.EndDate = "EndDate";
    XmlAttributeNames.Version = "Version";
    XmlAttributeNames.Aggregate = "Aggregate";
    XmlAttributeNames.SearchScope = "SearchScope";
    XmlAttributeNames.Format = "Format";
    XmlAttributeNames.Mailbox = "Mailbox";
    XmlAttributeNames.DestinationFormat = "DestinationFormat";
    XmlAttributeNames.FolderId = "FolderId";
    XmlAttributeNames.ItemId = "ItemId";
    XmlAttributeNames.IncludePermissions = "IncludePermissions";
    XmlAttributeNames.InitialName = "InitialName";
    XmlAttributeNames.FinalName = "FinalName";
    XmlAttributeNames.AuthenticationMethod = "AuthenticationMethod";
    XmlAttributeNames.Time = "Time";
    XmlAttributeNames.Name = "Name";
    XmlAttributeNames.Bias = "Bias";
    XmlAttributeNames.Kind = "Kind";
    XmlAttributeNames.SubscribeToAllFolders = "SubscribeToAllFolders";
    XmlAttributeNames.PublicFolderServer = "PublicFolderServer";
    XmlAttributeNames.IsArchive = "IsArchive";
    XmlAttributeNames.ReturnHighlightTerms = "ReturnHighlightTerms";
    XmlAttributeNames.IsExplicit = "IsExplicit";
    XmlAttributeNames.ClientExtensionUserIdentity = "UserId";
    XmlAttributeNames.ClientExtensionEnabledOnly = "EnabledOnly";
    XmlAttributeNames.SetClientExtensionActionId = "ActionId";
    XmlAttributeNames.ClientExtensionId = "ExtensionId";
    XmlAttributeNames.ClientExtensionIsAvailable = "IsAvailable";
    XmlAttributeNames.ClientExtensionIsMandatory = "IsMandatory";
    XmlAttributeNames.ClientExtensionIsEnabledByDefault = "IsEnabledByDefault";
    XmlAttributeNames.ClientExtensionProvidedTo = "ProvidedTo";
    XmlAttributeNames.ClientExtensionType = "Type";
    XmlAttributeNames.ClientExtensionScope = "Scope";
    XmlAttributeNames.ClientExtensionMarketplaceAssetID = "MarketplaceAssetId";
    XmlAttributeNames.ClientExtensionMarketplaceContentMarket = "MarketplaceContentMarket";
    XmlAttributeNames.ClientExtensionAppStatus = "AppStatus";
    XmlAttributeNames.ClientExtensionEtoken = "Etoken";
    XmlAttributeNames.ClientExtensionInstalledDateTime = "InstalledDateTime";
    XmlAttributeNames.IsTruncated = "IsTruncated";
    XmlAttributeNames.IsJunk = "IsJunk";
    XmlAttributeNames.MoveItem = "MoveItem";
    // xsi attributes
    XmlAttributeNames.Nil = "nil";
    XmlAttributeNames.Type = "type";
})(XmlAttributeNames = exports.XmlAttributeNames || (exports.XmlAttributeNames = {}));
